# tejim

## about

this is a configuration file standart the goal of which is to be simpistic, yet still robust enough.

its specification you can find [here](https://github.com/Spaceginner/tejim/wiki/Specification)

## features

- dictionary
- different value types
  - boolean
  - integer
  - floating-point
  - string

## why?

why not™ duh
